@@ -11,6 +11,19 @@
 FILE * tmpstdout;
 #undef stdout
 #define stdout tmpstdout
+
+/* For stderr, qhull already defines a dummy stderr qh_FILEstderr in
+   libqhull_r.h */
+#undef stderr
+#define stderr qh_FILEstderr
+
 /* PI has been defined by the R header files, but the Qhull package
    defines it again, so undefine it here. */
 #undef PI
+
+#include "qhull_ra.h"
+
+void freeQhull(qhT *qh);
+void qhullFinalizer(SEXP ptr);
+boolT hasPrintOption(qhT *qh, qh_PRINT format);
+int qhullNewQhull(qhT *qh, const SEXP p, char* cmd, const SEXP options, const SEXP tmpdir, unsigned int* pdim, unsigned int* pn, char* errstr1, char* errstr2);
